@@ -1,6 +1,7 @@
 
 # Set default logging handler to avoid "No handler found" warnings.
 import logging
+import warnings
 from logging import NullHandler
 
 logging.getLogger(__name__).addHandler(NullHandler())
@@ -30,10 +31,25 @@ def enable_log_level(level=logging.DEBUG):
     add_handler_level(level=level)
 
 
+# warn about available packages
+try:
+    import _align
+except ModuleNotFoundError:
+    warnings.warn("Couldn't find cython 'align' extension, defaulting to numba implementation")
+    _align = None
+
+try:
+    import pyemd
+except ModuleNotFoundError:
+    pyemd = None
+    warnings.warn("Couldn't import `pyemd` module, deactivating `wmd` method")
+
+
 from . import utils
 from .pipeline import pipeline, Results
 from .embeddings import Embeddings
 
+
 # package version
 import sys
 
